@@ -4,18 +4,19 @@ from __future__ import annotations
 from pathlib import Path
 
 import typer
+
 from snowcli import config
 from snowcli.config import AppConfig
 from snowcli.utils import print_db_cursor
 
 app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]})
-EnvironmentOption = typer.Option("dev", help='Environment name')
+EnvironmentOption = typer.Option("dev", help="Environment name")
 
 
 @app.command("list")
 def stage_list(
     environment: str = EnvironmentOption,
-    name=typer.Argument(None, help='Name of stage'),
+    name=typer.Argument(None, help="Name of stage"),
 ):
     """
     List stage contents
@@ -26,19 +27,19 @@ def stage_list(
         config.connectToSnowflake()
         if name:
             results = config.snowflake_connection.listStage(
-                database=env_conf.get('database'),
-                schema=env_conf.get('schema'),
-                role=env_conf.get('role'),
-                warehouse=env_conf.get('warehouse'),
+                database=env_conf.get("database"),
+                schema=env_conf.get("schema"),
+                role=env_conf.get("role"),
+                warehouse=env_conf.get("warehouse"),
                 name=name,
             )
             print_db_cursor(results)
         else:
             results = config.snowflake_connection.listStages(
-                database=env_conf.get('database'),
-                schema=env_conf.get('schema'),
-                role=env_conf.get('role'),
-                warehouse=env_conf.get('warehouse'),
+                database=env_conf.get("database"),
+                schema=env_conf.get("schema"),
+                role=env_conf.get("role"),
+                warehouse=env_conf.get("warehouse"),
             )
             print_db_cursor(results)
 
@@ -46,9 +47,9 @@ def stage_list(
 @app.command("get")
 def stage_get(
     environment: str = EnvironmentOption,
-    name: str = typer.Argument(..., help='Stage name'),
+    name: str = typer.Argument(..., help="Stage name"),
     path: Path = typer.Argument(
-        Path('.'),
+        Path("."),
         exists=False,
         file_okay=True,
         dir_okay=True,
@@ -65,10 +66,10 @@ def stage_get(
     if config.isAuth():
         config.connectToSnowflake()
         results = config.snowflake_connection.getStage(
-            database=env_conf.get('database'),
-            schema=env_conf.get('schema'),
-            role=env_conf.get('role'),
-            warehouse=env_conf.get('warehouse'),
+            database=env_conf.get("database"),
+            schema=env_conf.get("schema"),
+            role=env_conf.get("role"),
+            warehouse=env_conf.get("warehouse"),
             name=name,
             path=str(path),
         )
@@ -85,9 +86,17 @@ def stage_put(
         dir_okay=True,
         writable=True,
         resolve_path=True,
-        help="Directory location to store downloaded files",
+        help="File or directory to upload to stage",
+    ),
+    name: str = typer.Argument(..., help="Stage name"),
+    overwrite: bool = typer.Option(
+        False,
+        help="Overwrite existing files in stage",
+    ),
+    parallel: int = typer.Option(
+        4,
+        help="Number of parallel threads to use for upload",
     ),
-    name: str = typer.Argument(..., help='Stage name'),
 ):
     """
     Upload files to a stage from a local client
@@ -98,14 +107,16 @@ def stage_put(
         config.connectToSnowflake()
         filepath = str(path)
         if path.is_dir():
-            filepath = str(path) + '/*'
+            filepath = str(path) + "/*"
 
         results = config.snowflake_connection.putStage(
-            database=env_conf.get('database'),
-            schema=env_conf.get('schema'),
-            role=env_conf.get('role'),
-            warehouse=env_conf.get('warehouse'),
+            database=env_conf.get("database"),
+            schema=env_conf.get("schema"),
+            role=env_conf.get("role"),
+            warehouse=env_conf.get("warehouse"),
             name=name,
             path=str(filepath),
+            overwrite=overwrite,
+            parallel=parallel,
         )
         print_db_cursor(results)
