@@ -7,7 +7,7 @@ from snowcli.config import AppConfig
 from snowcli.utils import print_db_cursor
 
 app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]})
-EnvironmentOption = typer.Option("dev", help='Environment name')
+EnvironmentOption = typer.Option("dev", help="Environment name")
 
 
 @app.command("status")
@@ -20,9 +20,9 @@ def warehouse_status(environment: str = EnvironmentOption):
     if config.isAuth():
         config.connectToSnowflake()
         results = config.snowflake_connection.showWarehouses(
-            database=env_conf.get('database'),
-            schema=env_conf.get('schema'),
-            role=env_conf.get('role'),
-            warehouse=env_conf.get('warehouse'),
+            database=env_conf.get("database"),
+            schema=env_conf.get("schema"),
+            role=env_conf.get("role"),
+            warehouse=env_conf.get("warehouse"),
         )
-        print_db_cursor(results, ['name', 'state', 'queued', 'resumed_on'])
+        print_db_cursor(results, ["name", "state", "queued", "resumed_on"])
