@@ -5,8 +5,9 @@ use warehouse {warehouse};
 create or replace stage {name}_stage;
 
 create streamlit {name}
-  versions (main @st_db.st_schema.{name}_stage '/{file_name}')
-  warehouse=regress;
+  ROOT_LOCATION = @{database}.{schema}.{name}_stage
+  MAIN_FILE = '/{file_name}'
+  QUERY_WAREHOUSE = {warehouse};
 
 show streamlits;
 describe streamlit {name};
