@@ -3,5 +3,5 @@ from __future__ import annotations
 
 
 def test_help_option(runner):
-    result = runner.invoke(['--help'])
+    result = runner.invoke(["--help"])
     assert result.exit_code == 0
